This helper sets the `HF_TOKEN` environment variable for the duration of a code block and restores the previous value afterwards.
.with_hf_token(token, expr)Character scalar or NULL. When NULL, the current token (if any) is used. When non-NULL, the environment variable is temporarily set to this value.
Expression to evaluate within the temporary token context.